import java.util.Arrays;

public class ArrayUtility {
	
	/**
	 * combines a given 2D array into 1D array
	 * for example,
	 * { {1, 2}, {3, 4, 5} } -> {1, 2, 3, 4, 5}
	 * @param d
	 * @return 1D array of combine all elements from 2D array
	 */
	public static int[] merge(int[][] d) {
		int length = 0;
		for(int i = 0;i < d.length;i++)length+=d[i].length;
		int[] merged_array = new int[length];
		int current_index = 0;
		for(int i = 0;i < d.length;i++)for(int j = 0;j < d[i].length;j++) {
			merged_array[current_index] = d[i][j];
			current_index++;
		}
		return merged_array;
	}
	
	/** 
	 * splits a given 1D array into 2D array with n equal parts
	 * if the given array cannot be split into n equal part
	 * this method should return 2D array of size 0,0 (new int[0][0])
	 * @param d
	 * @param n number of parts for the target, 0 < n <= d.length
	 * @return 2D array
	 */
	public static int[][] split(int[] d, int n) {
		if(n<=0) return new int[0][0]; //Return to prevent ArithmeticException: / by zero and negative array index
		if (d.length%n!=0)return new int[0][0]; //Return, not array is not splittable
		int[][] splitted_array = new int[n][d.length/n]; //Create the splitted_array array and initialize it
		for(int i = 0;i < n;i++)for(int j = 0;j<d.length/n;j++)splitted_array[i][j] = d[j*n+i];
		return splitted_array;
	}

	public static void show(String[] x) {
		System.out.println(Arrays.toString(x));
	}

	public static void show(String[][] x2d) {
		for (String[] x : x2d) {
			show(x);
		}
	}

	public static void show(int[] x) {
		System.out.println(Arrays.toString(x));
	}
	
	public static void show(int[][] x2d) {
		for (int[] x : x2d) {
			show(x);
		}
	}
}
